@@ -12,7 +12,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let mut backend = BitMapBackend::new("examples/outputs/stock.png", (1024, 768));
     backend.open()?;
     let root: DrawingArea<_, _> = backend.into();
-    let font = Into::<FontDesc>::into("Arial").resize(30.0);
+    let font = Into::<FontDesc>::into("Arial").resize(50.0);
     root.fill(&RGBColor(255, 255, 255))?;
 
     let (to_date, from_date) = (
@@ -21,14 +21,15 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     );
 
     let mut chart = ChartBuilder::on(&root)
-        .set_x_label_size(40)
-        .set_y_label_size(40)
+        .x_label_area_size(40)
+        .y_label_area_size(40)
         .caption("MSFT Stock Price", &font)
-        .build_ranged::<RangedDate<_>, RangedCoordf32, _, _>(from_date..to_date, 110f32..135f32);
+        .build_ranged(from_date..to_date, 110f32..135f32);
 
-    let style: ShapeStyle = (&RGBColor(255, 255, 255)).into();
-
-    chart.configure_mesh().line_style_2(&style).draw()?;
+    chart
+        .configure_mesh()
+        .line_style_2(&RGBColor(255, 255, 255))
+        .draw()?;
 
     chart.draw_series(data.iter().map(|x| {
         CandleStick::<_, _>::new::<&RGBColor, &RGBColor>(
